pub struct VersionControl { /* private fields */ }Expand description
Version control system for workspaces
Implementations
Sourceimpl VersionControl
impl VersionControl
Sourcepub async fn create_commit(
&self,
workspace_id: Uuid,
author_id: Uuid,
message: String,
parent_id: Option<Uuid>,
version: i64,
snapshot: Value,
changes: Value,
) -> Result<Commit>
pub async fn create_commit( &self, workspace_id: Uuid, author_id: Uuid, message: String, parent_id: Option<Uuid>, version: i64, snapshot: Value, changes: Value, ) -> Result<Commit>
Sourcepub async fn get_commit(&self, commit_id: Uuid) -> Result<Commit>
pub async fn get_commit(&self, commit_id: Uuid) -> Result<Commit>
Sourcepub async fn get_history(
&self,
workspace_id: Uuid,
limit: Option<i32>,
) -> Result<Vec<Commit>>
pub async fn get_history( &self, workspace_id: Uuid, limit: Option<i32>, ) -> Result<Vec<Commit>>
Sourcepub async fn create_snapshot(
&self,
workspace_id: Uuid,
name: String,
description: Option<String>,
commit_id: Uuid,
created_by: Uuid,
) -> Result<Snapshot>
pub async fn create_snapshot( &self, workspace_id: Uuid, name: String, description: Option<String>, commit_id: Uuid, created_by: Uuid, ) -> Result<Snapshot>
Create a named snapshot
Errors
Returns an error if the commit does not exist or the database insert fails.
Sourcepub async fn get_snapshot(
&self,
workspace_id: Uuid,
name: &str,
) -> Result<Snapshot>
pub async fn get_snapshot( &self, workspace_id: Uuid, name: &str, ) -> Result<Snapshot>
Get a snapshot by name
Errors
Returns an error if the snapshot is not found or the database query fails.